
// **************************************
// Header Files
// **************************************

#include "device.h"

// **************************
// Class Declaration
// **************************

device::device(void)
{  // constructor
}

device::~device(void)
{  // destructor
}

device::device(const device &dev)
{  // copy constructor

  identifier=dev.GetId();
  driver=dev.GetDriver();
  busID=dev.GetBus();
  screen=dev.GetScreen();
  videoRam=dev.GetVideoRam();
  comment=dev.GetComment();

  identifierComment=dev.GetIdComment();
  driverComment=dev.GetDriverComment();
  busIDComment=dev.GetBusComment();
  screenComment=dev.GetScreenComment();
  videoRamComment=dev.GetVideoRamComment();

  for (unsigned int i=0; i<dev.GetOptionSize(); i++)
  {
    AddOption(dev.GetOption(i));
  }

}

device device::operator=(const device &dev)
{  // copy constructor

  Clear();

  identifier=dev.GetId();
  driver=dev.GetDriver();
  busID=dev.GetBus();
  screen=dev.GetScreen();
  videoRam=dev.GetVideoRam();
  comment=dev.GetComment();

  identifierComment=dev.GetIdComment();
  driverComment=dev.GetDriverComment();
  busIDComment=dev.GetBusComment();
  screenComment=dev.GetScreenComment();
  videoRamComment=dev.GetVideoRamComment();

  for (unsigned int i=0; i<dev.GetOptionSize(); i++)
  {
    AddOption(dev.GetOption(i));
  }

  return(*this);
}

void device::AddComment(const wxString& com)
{  // set comment

  comment.Add(com);
}

void device::SetId(const wxString& id, const wxString& com)
{  // set identifier

  identifier=id;
  identifierComment=com;
}

void device::SetDriver(const wxString& dr, const wxString& com)
{  // set driver

  driver=dr;
  driverComment=com;
}

void device::SetBus(const wxString& bus, const wxString& com)
{  // set bus type

  busID=bus;
  busIDComment=com;
}

void device::SetScreen(const wxString& scr, const wxString& com)
{  // set screen to use

  screen=scr;
  screenComment=com;
}

void device::SetVideoRam(const wxString& ram, const wxString& com)
{  // set video ram size

  videoRam=ram;
  videoRamComment=com;
}

void device::RemoveOption(const unsigned int index)
{  // remove option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("device::RemoveOption"), wxICON_ERROR);
    return;
  }

  options.Remove(index);
}

void device::AddOption(const option &opt)
{  // add option

  options.Add(opt);
}

void device::SetOption(const unsigned int index, const option& opt)
{  // set option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("device::SetOption"), wxICON_ERROR);
    return;
  }

  options[index]=opt;
}

void device::Clear(void)
{    // clear everything

  identifier=wxEmptyString;
  driver=wxEmptyString;
  busID=wxEmptyString;
  screen=wxEmptyString;
  videoRam=wxEmptyString;
  identifierComment=wxEmptyString;
  driverComment=wxEmptyString;
  busIDComment=wxEmptyString;
  screenComment=wxEmptyString;
  videoRamComment=wxEmptyString;
  comment.Clear();
  options.Clear();
}

const wxArrayString& device::GetComment(void) const
{  // return comment

  return(comment);
}

const wxString& device::GetId(void) const
{  // return identifier

  return(identifier);
}

const wxString& device::GetDriver(void) const
{  // retun driver name

  return(driver);
}

const wxString& device::GetBus(void) const
{  // return bus id

  return(busID);
}

const wxString& device::GetScreen(void) const
{  // return used screen

  return(screen);
}

const wxString& device::GetVideoRam(void) const
{  // return video ram size

  return(videoRam);
}

const wxString& device::GetIdComment(void) const
{  // return identifier comment

  return(identifierComment);
}

const wxString& device::GetDriverComment(void) const
{  // retun driver name comment

  return(driverComment);
}

const wxString& device::GetBusComment(void) const
{  // return bus id comment

  return(busIDComment);
}

const wxString& device::GetScreenComment(void) const
{  // return used screen comment

  return(screenComment);
}

const wxString& device::GetVideoRamComment(void) const
{  // return video ram size comment

  return(videoRamComment);
}

const option& device::GetOption(const unsigned int index) const
{  // get single option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("device::GetOption"), wxICON_ERROR);
  }

  return(options.Get(index));
}

option& device::GetOptionE(const unsigned int index)
{  // get single option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("device::GetOption"), wxICON_ERROR);
  }

  return(options[index]);
}

unsigned int device::GetOptionSize(void) const
{  // return size of options

  return(options.GetSize());
}

