
// **************************************
// Header Files
// **************************************

#include "deviceList.h"

// **************************
// Class Declaration
// **************************

deviceList::deviceList(void)
{  // constructor
  size=0;
  dList=NULL;
}

deviceList::~deviceList(void)
{  // destructor
  if (dList) delete [] dList;
  dList=NULL;
}

deviceList::deviceList(const deviceList &dis)
{  // copy constructor

  size=dis.GetSize();
  dList=new device[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }
}

deviceList deviceList::operator=(const deviceList &dis)
{  // copy constructor

  Clear();

  size=dis.GetSize();
  dList=new device[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }

  return(*this);
}

void deviceList::Remove(const unsigned int index)
{  // remove a device

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("deviceList::Remove"), wxICON_ERROR);
    return;
  }

  unsigned int i;  // loop counter

  if (size>1)
  {
    device *dis=new device[size-1];

    for (i=0; i<index; i++) dis[i]=dList[i];        // copy old entries
    for (i=index+1; i<size; i++) dis[i-1]=dList[i]; // and ignore index

    if (dList) delete [] dList;   // delete old list
    dList=dis;         // set pointer
    dis=NULL;
  }
  else
  {
    if (dList) delete [] dList;   // delete old list
    dList=NULL;         // set pointer
  }

  size--;              // set size
}

void deviceList::Add(const device& dis)
{  // add an option and value

  device *dL=new device[size+1];

  for (unsigned int i=0; i<size; i++) dL[i]=dList[i]; // copy old entries

  dL[size]=dis;   // set las entry

  if (dList) delete [] dList;   // delete old list
  dList=dL;         // set pointer
  dL=NULL;

  size++;
}

void deviceList::Clear(void)
{    // clear everything

  if (dList) delete [] dList;
  dList=NULL;

  size=0;
}

const device& deviceList::Get(const unsigned int index) const
{  // get single device

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("deviceList::Get"), wxICON_ERROR);
  }

  return(dList[index]);
}

device& deviceList::operator[](const unsigned int index)
{  // get single device

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("deviceList::operator[]"), wxICON_ERROR);
    return(dList[index]);  // return empty device
  }

  return(dList[index]);
}

unsigned int deviceList::GetSize(void) const
{  // return size

  return(size);

}
