
// **************************************
// Header Files
// **************************************

#include "display.h"

// **************************
// Class Declaration
// **************************

display::display(void)
{  // constructor
}

display::~display(void)
{  // destructor
}

display::display(const display &dis)
{  // copy constructor

  depth=dis.GetDepth();
  viewport=dis.GetViewPort();
  virtualE=dis.GetVirtual();
  comment=dis.GetComment();
  depthComment=dis.GetDepthComment();
  viewportComment=dis.GetViewPortComment();
  virtualEComment=dis.GetVirtualComment();
  modesComment=dis.GetModeComment();

  for (unsigned int i=0; i<dis.GetOptionSize(); i++)
  {
    AddOption(dis.GetOption(i));
  }

  for (unsigned int j=0; j<dis.GetModeSize(); j++)
  {
    AddMode(dis.GetMode(j));
  }

}

display display::operator=(const display &dis)
{  // copy constructor

  Clear();

  depth=dis.GetDepth();
  viewport=dis.GetViewPort();
  virtualE=dis.GetVirtual();
  comment=dis.GetComment();
  depthComment=dis.GetDepthComment();
  viewportComment=dis.GetViewPortComment();
  virtualEComment=dis.GetVirtualComment();
  modesComment=dis.GetModeComment();

  for (unsigned int i=0; i<dis.GetOptionSize(); i++)
  {
    AddOption(dis.GetOption(i));
  }

  for (unsigned int j=0; j<dis.GetModeSize(); j++)
  {
    AddMode(dis.GetMode(j));
  }

  return(*this);
}

void display::AddComment(const wxString& com)
{  // set comment

  comment.Add(com);
}


void display::SetDepth(const wxString& dd, const wxString& com)
{  // set depth

  depth=dd;
  depthComment=com;
}

void display::SetViewPort(const wxString& vw, const wxString& com)
{  // set viewport

  viewport=vw;
  viewportComment=com;
}

void display::SetVirtual(const wxString& vi, const wxString& com)
{  // set virtual

  virtualE=vi;
  virtualEComment=com;
}

void display::RemoveOption(const unsigned int index)
{  // remove option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::RemoveOption"), wxICON_ERROR);
    return;
  }

  options.Remove(index);
}

void display::AddOption(const option &opt)
{  // add option

  options.Add(opt);
}

void display::SetOption(const unsigned int index, const option& opt)
{  // set option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::SetOption"), wxICON_ERROR);
    return;
  }

  options[index]=opt;
}

void display::RemoveMode(const unsigned int index)
{  // remove modeline

  if (index>=modes.GetCount())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::RemoveMode"), wxICON_ERROR);
    return;
  }

  modes.RemoveAt(index);
}

void display::AddMode(const wxString& mode)
{  // add modeline

  modes.Add(mode);
}

void display::SetModeComment(const wxString& com)
{  // set mode comment
  modesComment=com;
}

void display::SetMode(const unsigned int index, const wxString& mode)
{  // set mode

  if (index>=modes.GetCount())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::SetMode"), wxICON_ERROR);
    return;
  }

  modes[index]=mode;
}

void display::Clear(void)
{    // clear everything

  depth=wxEmptyString;
  virtualE=wxEmptyString;
  viewport=wxEmptyString;
  depthComment=wxEmptyString;
  virtualEComment=wxEmptyString;
  viewportComment=wxEmptyString;
  comment.Clear();
  options.Clear();
  modes.Clear();
  modesComment=wxEmptyString;
}

const wxString& display::GetDepth(void) const
{  // return depth

  return(depth);
}

const wxString& display::GetViewPort(void) const
{  // return viewport

  return(viewport);
}

const wxString& display::GetVirtual(void) const
{  // return virtual

  return(virtualE);
}

const wxArrayString& display::GetComment(void) const
{  // return comment

  return(comment);
}

const wxString& display::GetDepthComment(void) const
{  // return depth Comment

  return(depthComment);
}

const wxString& display::GetViewPortComment(void) const
{  // return viewport Comment

  return(viewportComment);
}

const wxString& display::GetVirtualComment(void) const
{  // return virtual Comment

  return(virtualEComment);
}

const option& display::GetOption(const unsigned int index) const
{  // get single option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::GetOption"), wxICON_ERROR);
  }

  return(options.Get(index));
}

option& display::GetOptionE(const unsigned int index)
{  // get single option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::GetOption"), wxICON_ERROR);
  }

  return(options[index]);
}

unsigned int display::GetOptionSize(void) const
{  // return size of options

  return(options.GetSize());
}

const wxString& display::GetMode(const unsigned int index) const
{  // get modeline name

  if (index>=modes.GetCount())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("display::GetMode"), wxICON_ERROR);
  }

  return(modes.Item(index));
}

const wxString& display::GetModeComment(void) const
{  // get modeline comment

  return(modesComment);
}

unsigned int display::GetModeSize(void) const
{  // return number of modes

  return(modes.GetCount());

}




