
// **************************************
// Header Files
// **************************************

#include "displayList.h"

// **************************
// Class Declaration
// **************************

displayList::displayList(void)
{  // constructor
  size=0;
  dList=NULL;
}

displayList::~displayList(void)
{  // destructor
  if (dList) delete [] dList;
  dList=NULL;
}

displayList::displayList(const displayList &dis)
{  // copy constructor

  size=dis.GetSize();
  dList=new display[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }
}

displayList displayList::operator=(const displayList &dis)
{  // copy constructor

  Clear();

  size=dis.GetSize();
  dList=new display[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }

  return(*this);
}

void displayList::Remove(const unsigned int index)
{  // remove a display

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("displayList::Remove"), wxICON_ERROR);
    return;
  }

  unsigned int i;  // loop counter

  if (size>1)
  {
    display *dis=new display[size-1];

    for (i=0; i<index; i++) dis[i]=dList[i];        // copy old entries
    for (i=index+1; i<size; i++) dis[i-1]=dList[i]; // and ignore index

    if (dList) delete [] dList;   // delete old list
    dList=dis;         // set pointer
    dis=NULL;
  }
  else
  {
    if (dList) delete [] dList;   // delete old list
    dList=NULL;         // set pointer
  }

  size--;              // set size
}

void displayList::Add(const display& dis)
{  // add an option and value

  display *dL=new display[size+1];

  for (unsigned int i=0; i<size; i++) dL[i]=dList[i]; // copy old entries

  dL[size]=dis;   // set las entry

  if (dList) delete [] dList;   // delete old list
  dList=dL;         // set pointer
  dL=NULL;

  size++;
}

void displayList::Clear(void)
{    // clear everything

  if (dList) delete [] dList;
  dList=NULL;

  size=0;
}

const display& displayList::Get(const unsigned int index) const
{  // get single display

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("displayList::Get"), wxICON_ERROR);
  }

  return(dList[index]);
}

display& displayList::operator[](const unsigned int index)
{  // get single device

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("displayList::operator[]"), wxICON_ERROR);
    return(dList[index]);  // return empty device
  }

  return(dList[index]);
}


unsigned int displayList::GetSize(void) const
{  // return size

  return(size);

}
