
// **************************************
// Header Files
// **************************************

#include "fileList.h"

// **************************
// Class Declaration
// **************************

fileList::fileList(void)
{  // constructor
}

fileList::~fileList(void)
{  // destructor
}

fileList::fileList(const fileList &list)
{  // copy constructor

  unsigned int i;

  comment=list.GetComment();

  for (i=0; i<list.GetFontPathSize(); i++)
  {
    AddFontPath(list.GetFontPath(i), list.FontPathIsActive(i), list.GetFontPathComment(i));
  }
  for (i=0; i<list.GetModulePathSize(); i++)
  {
    AddModulePath(list.GetModulePath(i), list.ModulePathIsActive(i), list.GetModulePathComment(i));
  }
  for (i=0; i<list.GetRgbPathSize(); i++)
  {
    AddRgbPath(list.GetRgbPath(i), list.RgbPathIsActive(i), list.GetRgbPathComment(i));
  }
}

fileList fileList::operator=(const fileList &list)
{  // copy constructor

  // clear old entries
  Clear();

  unsigned int i;


  comment=list.GetComment();

  for (i=0; i<list.GetFontPathSize(); i++)
  {
    AddFontPath(list.GetFontPath(i), list.FontPathIsActive(i), list.GetFontPathComment(i));
  }
  for (i=0; i<list.GetModulePathSize(); i++)
  {
    AddModulePath(list.GetModulePath(i), list.ModulePathIsActive(i), list.GetModulePathComment(i));
  }
  for (i=0; i<list.GetRgbPathSize(); i++)
  {
    AddRgbPath(list.GetRgbPath(i), list.RgbPathIsActive(i), list.GetRgbPathComment(i));
  }

  return(*this);
}

void fileList::Clear(void)
{  // clear all

  comment.Clear();
  fontPaths.Clear();
  modulePaths.Clear();
  rgbPaths.Clear();
}

void fileList::RemoveFontPath(const unsigned int index)
{  // remove a font path

  if (index>=fontPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::RemoveFontPath"), wxICON_ERROR);
    return;
  }

  fontPaths.Remove(index);
}

void fileList::AddFontPath(const wxString& path, const bool act, const wxString& com)
{  // add a font path

  fontPaths.Add(path, wxEmptyString, com);
  fontPaths[fontPaths.GetSize()-1].SetActive(act);
}

void fileList::SetFontPath(const unsigned int index, const wxString& path, const wxString& com)
{ // set font path

  if (index>=fontPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::SetFontPath"), wxICON_ERROR);
    return;
  }

  fontPaths[index].SetName(path);
  fontPaths[index].SetComment(com);
}

void fileList::SetFontPathActive(const unsigned int index, const bool act)
{ // set font path active

  if (index>=fontPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::SetFontPathActive"), wxICON_ERROR);
  }

  fontPaths[index].SetActive(act);
}

const wxString& fileList::GetFontPath(const unsigned int index) const
{  // get single font path

  if (index>=fontPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::GetFontPath"), wxICON_ERROR);
  }

  return(fontPaths.Get(index).GetName());
}

const wxString& fileList::GetFontPathComment(const unsigned int index) const
{  // get single font path

  if (index>=fontPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::GetFontPathComment"), wxICON_ERROR);
  }

  return(fontPaths.Get(index).GetComment());
}

unsigned int fileList::GetFontPathSize(void) const
{  // return size

  return(fontPaths.GetSize());
}

bool fileList::FontPathIsActive(const unsigned int index) const
{    // return status

  if (index>=fontPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::FontPathIsActive"), wxICON_ERROR);
  }

  return(fontPaths.Get(index).IsActive());
}

void fileList::RemoveModulePath(const unsigned int index)
{  // remove a module path

  if (index>=modulePaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::RemoveModulePath"), wxICON_ERROR);
    return;
  }

  modulePaths.Remove(index);
}

void fileList::AddModulePath(const wxString& path, const bool act, const wxString& com)
{  // add a module path

  modulePaths.Add(path, wxEmptyString, com);
  modulePaths[modulePaths.GetSize()-1].SetActive(act);
}

void fileList::SetModulePath(const unsigned int index, const wxString& path, const wxString& com)
{ // set module path

  if (index>=modulePaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::SetModulePath"), wxICON_ERROR);
    return;
  }

  modulePaths[index].SetName(path);
  modulePaths[index].SetComment(com);
}

void fileList::SetModulePathActive(const unsigned int index, const bool act)
{ // set module path active

  if (index>=modulePaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::SetModulePathActive"), wxICON_ERROR);
  }

  modulePaths[index].SetActive(act);
}

const wxString& fileList::GetModulePath(const unsigned int index) const
{  // get single module path

  if (index>=modulePaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::GetModulePath"), wxICON_ERROR);
  }

  return(modulePaths.Get(index).GetName());
}

const wxString& fileList::GetModulePathComment(const unsigned int index) const
{  // get single module path comment

  if (index>=modulePaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::GetModulePathComment"), wxICON_ERROR);
  }

  return(modulePaths.Get(index).GetComment());
}

unsigned int fileList::GetModulePathSize(void) const
{  // return size

  return(modulePaths.GetSize());
}

bool fileList::ModulePathIsActive(const unsigned int index) const
{    // return status

  if (index>=modulePaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::ModulePathIsActive"), wxICON_ERROR);
  }

  return(modulePaths.Get(index).IsActive());
}

void fileList::RemoveRgbPath(const unsigned int index)
{  // remove a rgb path

  if (index>=rgbPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::RemoveRgbPath"), wxICON_ERROR);
    return;
  }

  rgbPaths.Remove(index);
}

void fileList::AddRgbPath(const wxString& path, const bool act, const wxString& com)
{  // add a rgb path

  rgbPaths.Add(path, wxEmptyString, com);
  rgbPaths[rgbPaths.GetSize()-1].SetActive(act);
}

void fileList::SetRgbPath(const unsigned int index, const wxString& path, const wxString& com)
{ // set rgb path

  if (index>=rgbPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::SetRgbPath"), wxICON_ERROR);
    return;
  }

  rgbPaths[index].SetName(path);
  rgbPaths[index].SetComment(com);
}

void fileList::SetRgbPathActive(const unsigned int index, const bool act)
{ // set rgb path active

  if (index>=rgbPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::SetRgbPathActive"), wxICON_ERROR);
  }

  rgbPaths[index].SetActive(act);
}

const wxString& fileList::GetRgbPath(const unsigned int index) const
{  // get single rgb path

  if (index>=rgbPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::GetRgbPath"), wxICON_ERROR);
  }

  return(rgbPaths.Get(index).GetName());
}

const wxString& fileList::GetRgbPathComment(const unsigned int index) const
{  // get single rgb path comment

  if (index>=rgbPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::GetRgbPathComment"), wxICON_ERROR);
  }

  return(rgbPaths.Get(index).GetComment());
}

unsigned int fileList::GetRgbPathSize(void) const
{  // return size

  return(rgbPaths.GetSize());
}

bool fileList::RgbPathIsActive(const unsigned int index) const
{    // return status

  if (index>=rgbPaths.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("fileList::RgbPathIsActive"), wxICON_ERROR);
  }

  return(rgbPaths.Get(index).IsActive());
}

void fileList::AddComment(wxString& com)
{     // set comment
  comment.Add(com);
}

const wxArrayString& fileList::GetComment(void) const
{    // get comment
  return(comment);
}



