#ifndef FILELIST_H
#define FILELIST_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionList.h"

// **************************
// Class Definition
// **************************

class fileList
{
public:
  fileList(void);   // constructor
  ~fileList(void);   // destructor
  fileList(const fileList &list); // copy constructor

  fileList operator=(const fileList &list); // copy constructor

  void RemoveFontPath(const unsigned int index);  // remove a font path
  void AddFontPath(const wxString& path, const bool act, const wxString& com=wxEmptyString);  // add a font path
  void SetFontPath(const unsigned int index, const wxString& path, const wxString& com=wxEmptyString); // set font path
  void SetFontPathActive(const unsigned int index, const bool act); // set font path active
  const wxString& GetFontPath(const unsigned int index) const;    // get single font path
  const wxString& GetFontPathComment(const unsigned int index) const;    // get single font path comment
  bool FontPathIsActive(const unsigned int index) const;    // return status
  unsigned int GetFontPathSize(void) const;                // return size

  void RemoveModulePath(const unsigned int index);  // remove a module path
  void AddModulePath(const wxString& path, const bool act, const wxString& com=wxEmptyString);  // add a module path
  void SetModulePath(const unsigned int index, const wxString& path, const wxString& com=wxEmptyString); // set module path
  void SetModulePathActive(const unsigned int index, const bool act); // set module path active
  const wxString& GetModulePath(const unsigned int index) const;    // get single module path
  const wxString& GetModulePathComment(const unsigned int index) const;    // get single module path comment
  bool ModulePathIsActive(const unsigned int index) const;    // return status
  unsigned int GetModulePathSize(void) const;                // return size

  void RemoveRgbPath(const unsigned int index);  // remove a Rgb path
  void AddRgbPath(const wxString& path, const bool act, const wxString& com=wxEmptyString);  // add a Rgb path
  void SetRgbPath(const unsigned int index, const wxString& path, const wxString& com=wxEmptyString); // set Rgb path
  void SetRgbPathActive(const unsigned int index, const bool act); // set Rgb path active
  const wxString& GetRgbPath(const unsigned int index) const;    // get single Rgb path
  const wxString& GetRgbPathComment(const unsigned int index) const;    // get single Rgb path comment
  bool RgbPathIsActive(const unsigned int index) const;    // return status
  unsigned int GetRgbPathSize(void) const;                // return size

  void AddComment(wxString& com);     // set comment
  const wxArrayString& GetComment(void) const;    // get comment

  void Clear(void);   // clear everything

private:
  wxArrayString comment;        // comment
  optionList fontPaths;       // font paths
  optionList modulePaths;       // module paths
  optionList rgbPaths;       // rgb paths
};

#endif // FILELIST_H
