
// **************************************
// Header Files
// **************************************

#include "inputDevice.h"

// **************************
// Class Declaration
// **************************

inputDevice::inputDevice(void)
{  // constructor
}

inputDevice::~inputDevice(void)
{  // destructor
}

inputDevice::inputDevice(const inputDevice &dev)
{  // copy constructor

  identifier=dev.GetId();
  driver=dev.GetDriver();
  identifierComment=dev.GetIdComment();
  driverComment=dev.GetDriverComment();
  comment=dev.GetComment();

  for (unsigned int i=0; i<dev.GetOptionSize(); i++)
  {
    AddOption(dev.GetOption(i));
  }

}

inputDevice inputDevice::operator=(const inputDevice &dev)
{  // copy constructor

  Clear(); // clear all

  identifier=dev.GetId();
  driver=dev.GetDriver();
  identifierComment=dev.GetIdComment();
  driverComment=dev.GetDriverComment();
  comment=dev.GetComment();

  for (unsigned int i=0; i<dev.GetOptionSize(); i++)
  {
    AddOption(dev.GetOption(i));
  }

  return(*this);
}

void inputDevice::AddComment(const wxString& com)
{  // set comment

  comment.Add(com);
}

void inputDevice::SetId(const wxString& id, const wxString& com)
{  // set identifier

  identifier=id;
  identifierComment=com;
}

void inputDevice::SetDriver(const wxString& dr, const wxString& com)
{  // set driver

  driver=dr;
  driverComment=com;
}

const wxArrayString& inputDevice::GetComment(void) const
{  // return comment

  return(comment);
}

const wxString& inputDevice::GetId(void) const
{  // return identifier

  return(identifier);
}

const wxString& inputDevice::GetDriver(void) const
{  // retun driver name

  return(driver);
}

const wxString& inputDevice::GetIdComment(void) const
{  // return identifier comment

  return(identifierComment);
}

const wxString& inputDevice::GetDriverComment(void) const
{  // retun driver name comment

  return(driverComment);
}

void inputDevice::RemoveOption(const unsigned int index)
{  // remove option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDevice::RemoveOption"), wxICON_ERROR);
    return;
  }

  options.Remove(index);
}

void inputDevice::AddOption(const option &opt)
{  // add option

  options.Add(opt);
}

void inputDevice::SetOption(const unsigned int index, const option& opt)
{  // set option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDevice::SetOption"), wxICON_ERROR);
    return;
  }

  options[index]=opt;
}

void inputDevice::Clear(void)
{    // clear everything

  comment.Clear();
  identifier=wxEmptyString;
  driver=wxEmptyString;
  identifierComment=wxEmptyString;
  driverComment=wxEmptyString;
  options.Clear();
}

const option& inputDevice::GetOption(const unsigned int index) const
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDevice::GetOption"), wxICON_ERROR);
  }

  return(options.Get(index));
}

option& inputDevice::GetOptionE(const unsigned int index)
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDevice::GetOptionE"), wxICON_ERROR);
  }

  return(options[index]);
}

unsigned int inputDevice::GetOptionSize(void) const
{  // return size of options

  return(options.GetSize());
}

