
// **************************************
// Header Files
// **************************************

#include "inputDeviceList.h"

// **************************
// Class Declaration
// **************************

inputDeviceList::inputDeviceList(void)
{  // constructor
  size=0;
  dList=NULL;
}

inputDeviceList::~inputDeviceList(void)
{  // destructor
  if (dList) delete [] dList;
  dList=NULL;
}

inputDeviceList::inputDeviceList(const inputDeviceList &dis)
{  // copy constructor

  size=dis.GetSize();
  dList=new inputDevice[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }
}

inputDeviceList inputDeviceList::operator=(const inputDeviceList &dis)
{  // copy constructor

  Clear();

  size=dis.GetSize();
  dList=new inputDevice[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }

  return(*this);
}

void inputDeviceList::Remove(const unsigned int index)
{  // remove a inputDevice

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDeviceList::Remove"), wxICON_ERROR);
    return;
  }

  unsigned int i;  // loop counter

  if (size>1)
  {
    inputDevice *dis=new inputDevice[size-1];

    for (i=0; i<index; i++) dis[i]=dList[i];        // copy old entries
    for (i=index+1; i<size; i++) dis[i-1]=dList[i]; // and ignore index

    if (dList) delete [] dList;   // delete old list
    dList=dis;         // set pointer
    dis=NULL;
  }
  else
  {
    if (dList) delete [] dList;   // delete old list
    dList=NULL;         // set pointer
  }

  size--;              // set size
}

void inputDeviceList::Add(const inputDevice& dis)
{  // add an option and value

  inputDevice *dL=new inputDevice[size+1];

  for (unsigned int i=0; i<size; i++) dL[i]=dList[i]; // copy old entries

  dL[size]=dis;   // set las entry

  if (dList) delete [] dList;   // delete old list
  dList=dL;         // set pointer
  dL=NULL;

  size++;
}

void inputDeviceList::Clear(void)
{    // clear everything

  if (dList) delete [] dList;
  dList=NULL;

  size=0;
}

const inputDevice& inputDeviceList::Get(const unsigned int index) const
{  // get single inputDevice

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDeviceList::Get"), wxICON_ERROR);
  }

  return(dList[index]);
}

inputDevice& inputDeviceList::operator[](const unsigned int index)
{  // get single device

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("inputDeviceList::operator[]"), wxICON_ERROR);
    return(dList[index]);  // return empty device
  }

  return(dList[index]);
}


unsigned int inputDeviceList::GetSize(void) const
{  // return size

  return(size);

}
