
// **************************************
// Header Files
// **************************************

#include "moduleList.h"

// **************************
// Class Declaration
// **************************

moduleList::moduleList(void)
{  // constructor
  options=NULL;
}

moduleList::~moduleList(void)
{  // destructor

  if (options) delete [] options;
  options=NULL;
}

moduleList::moduleList(const moduleList &list)
{  // copy constructor

  options=NULL;
  comment=list.GetComment();

  for (unsigned int i=0; i<list.GetSize(); i++)
  {
    Add(list.Get(i), list.IsActive(i), list.GetModuleComment(i));

    for (unsigned int j=0; j<list.GetOptionSize(i); j++)
    {
      AddOption(i, list.GetOption(i,j));
    }
  }
}

moduleList moduleList::operator=(const moduleList &list)
{  // copy constructor

  // clear old entries
  Clear();

  comment=list.GetComment();

  for (unsigned int i=0; i<list.GetSize(); i++)
  {
    Add(list.Get(i), list.IsActive(i), list.GetModuleComment(i));

    for (unsigned int j=0; j<list.GetOptionSize(i); j++)
    {
      AddOption(i, list.GetOption(i,j));
    }
  }

  return(*this);
}

void moduleList::Remove(const unsigned int index)
{  // remove a module

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::Remove"), wxICON_ERROR);
    return;
  }

  modules.Remove(index);  // remove module

  unsigned int i;  // loop counter
  unsigned int size=modules.GetSize();

  if (size>1)
  {
    optionList *opt=new optionList[size-1];

    for (i=0; i<index; i++) opt[i]=options[i];        // copy old entries
    for (i=index+1; i<size; i++) opt[i-1]=options[i]; // and ignore index

    if (options) delete [] options;   // delete old options
    options=opt;         // set pointer
    opt=NULL;
  }
  else
  {
    if (options) delete [] options;   // delete old list
    options=NULL;         // set pointer
  }
}

void moduleList::Add(const wxString& mod, const bool act, const wxString& com)
{  // add a module

  modules.Add(mod, wxEmptyString, com);
  modules[modules.GetSize()-1].SetActive(act);

  optionList *opt=new optionList[modules.GetSize()];

  for (unsigned int i=0; i<modules.GetSize()-1; i++) opt[i]=options[i]; // copy old entries

  // Note: Last new option in opt keeps empty.

  if (options) delete [] options;   // delete old options
  options=opt;         // set pointer
  opt=NULL;
}

void moduleList::Set(const unsigned int index, const wxString& mod, const wxString& com)   // set module
{
  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::Set"), wxICON_ERROR);
    return;
  }

  modules[index].SetName(mod);
  modules[index].SetComment(com);

}

void moduleList::Clear(void)
{  // clear all

  modules.Clear();
  comment.Clear();

  if (options) delete [] options;
  options=NULL;
}

const wxString& moduleList::Get(const unsigned int index) const
{  // get module name

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::Get"), wxICON_ERROR);
  }

  return(modules.Get(index).GetName());
}

const wxString& moduleList::GetModuleComment(const unsigned int index) const
{  // get module name

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::GetModuleComment"), wxICON_ERROR);
  }

  return(modules.Get(index).GetComment());
}

void moduleList::RemoveOption(const unsigned int index1, const unsigned int index2)
{  // remove an option module

  if (index1>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::RemoveOption"), wxICON_ERROR);
    return;
  }

  options[index1].Remove(index2);

}

void moduleList::AddOption(const unsigned int index, const option& opt)
{  // add an option to a module

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::AddOption"), wxICON_ERROR);
    return;
  }

  options[index].Add(opt);

}

void moduleList::SetOption(const unsigned int index1, const unsigned int index2, const option& opt)
{  // set an option and value

  if (index1>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::SetOption"), wxICON_ERROR);
    return;
  }

  options[index1][index2]=opt;
}

const option& moduleList::GetOption(const unsigned int index1, const unsigned int index2) const
{  // get option of a module

  if (index1>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::GetOption"), wxICON_ERROR);
  }

  return(options[index1].Get(index2));
}

option& moduleList::GetOptionE(const unsigned int index1, const unsigned int index2)
{  // get option of a module

  if (index1>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::GetOptionE"), wxICON_ERROR);
  }

  return(options[index1][index2]);
}

unsigned int moduleList::GetSize(void) const
{  // return size

  return(modules.GetSize());
}

unsigned int moduleList::GetOptionSize(const unsigned int index) const
{  // return size

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::GetOptionSize"), wxICON_ERROR);
    return(0);
  }

  return(options[index].GetSize());
}

void moduleList::SetActive(const unsigned int index, const bool act)
{  // set active status

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::SetActive"), wxICON_ERROR);
    return;
  }

  modules[index].SetActive(act);
}

bool moduleList::IsActive(const unsigned int index) const
{  // return active status

  if (index>=modules.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("moduleList::IsActive"), wxICON_ERROR);
    return(false);
  }

  return(modules.Get(index).IsActive());
}

const wxArrayString& moduleList::GetComment(void) const
{    // get comment
  return(comment);
}

void moduleList::AddComment(const wxString& com)
{   // set comment
  comment.Add(com);
}


