
// **************************************
// Header Files
// **************************************

#include "monitor.h"

// **************************
// Class Declaration
// **************************

monitor::monitor(void)
{  // constructor
}

monitor::~monitor(void)
{  // destructor
}

monitor::monitor(const monitor &mon)
{  // copy constructor

  identifier=mon.GetId();
  horSync=mon.GetHorSync();
  vertRefresh=mon.GetVertRef();
  displaySize=mon.GetDisplaySize();
  gamma=mon.GetGamma();
  identifierComment=mon.GetIdComment();
  horSyncComment=mon.GetHorSyncComment();
  vertRefreshComment=mon.GetVertRefComment();
  displaySizeComment=mon.GetDisplaySizeComment();
  gammaComment=mon.GetGammaComment();
  comment=mon.GetComment();

  for (unsigned int i=0; i<mon.GetOptionSize(); i++)
  {
    AddOption(mon.GetOption(i));
  }

  for (unsigned int j=0; j<mon.GetModelineSize(); j++)
  {
    AddModeline(mon.GetModeline(j));
  }

}

monitor monitor::operator=(const monitor &mon)
{  // copy constructor

  Clear();

  identifier=mon.GetId();
  horSync=mon.GetHorSync();
  vertRefresh=mon.GetVertRef();
  displaySize=mon.GetDisplaySize();
  gamma=mon.GetGamma();
  identifierComment=mon.GetIdComment();
  horSyncComment=mon.GetHorSyncComment();
  vertRefreshComment=mon.GetVertRefComment();
  displaySizeComment=mon.GetDisplaySizeComment();
  gammaComment=mon.GetGammaComment();
  comment=mon.GetComment();

  for (unsigned int i=0; i<mon.GetOptionSize(); i++)
  {
    AddOption(mon.GetOption(i));
  }

  for (unsigned int j=0; j<mon.GetModelineSize(); j++)
  {
    AddModeline(mon.GetModeline(j));
  }

  return(*this);
}

void monitor::AddComment(const wxString& com)
{  // set comment

  comment.Add(com);
}

void monitor::SetId(const wxString& id, const wxString& com)
{  // set identifier

  identifier=id;
  identifierComment=com;
}

void monitor::SetHorSync(const wxString& hor, const wxString& com)
{  // set horizontal sync

  horSync=hor;
  horSyncComment=com;
}

void monitor::SetVertRef(const wxString& ver, const wxString& com)
{  // set vertical refresh

  vertRefresh=ver;
  vertRefreshComment=com;
}

void monitor::SetDisplaySize(const wxString& size, const wxString& com)
{  // set display size

  displaySize=size;
  displaySizeComment=com;
}

void monitor::SetGamma(const wxString& gam, const wxString& com)
{  // set gamma

  gamma=gam;
  gammaComment=com;
}

void monitor::RemoveOption(const unsigned int index)
{  // remove option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::RemoveOption"), wxICON_ERROR);
    return;
  }

  options.Remove(index);
}

void monitor::AddOption(const option &opt)
{  // add option

  options.Add(opt);
}

void monitor::SetOption(const unsigned int index, const option& opt)
{  // set option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::SetOption"), wxICON_ERROR);
    return;
  }

  options[index]=opt;
}

void monitor::RemoveModeline(const unsigned int index)
{  // remove modeline

  if (index>=modelines.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::RemoveModeline"), wxICON_ERROR);
    return;
  }

  modelines.Remove(index);
}

void monitor::AddModeline(const option &opt)
{  // add modeline

  modelines.Add(opt);
}

void monitor::SetModeline(const unsigned int index, const option& opt)
{  // set modeline

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::SetModeline"), wxICON_ERROR);
    return;
  }

  modelines[index]=opt;
}

void monitor::Clear(void)
{    // clear everything

  identifier=wxEmptyString;
  horSync=wxEmptyString;
  vertRefresh=wxEmptyString;
  displaySize=wxEmptyString;
  gamma=wxEmptyString;
  identifierComment=wxEmptyString;
  horSyncComment=wxEmptyString;
  vertRefreshComment=wxEmptyString;
  displaySizeComment=wxEmptyString;
  gammaComment=wxEmptyString;
  comment.Clear();
  options.Clear();
  modelines.Clear();
}

const wxArrayString& monitor::GetComment(void) const
{  // return comment

  return(comment);
}

const wxString& monitor::GetId(void) const
{  // return identifier

  return(identifier);
}

const wxString& monitor::GetHorSync(void) const
{  // return horizontal sync

  return(horSync);
}

const wxString& monitor::GetVertRef(void) const
{  // return vertical refresh

  return(vertRefresh);
}

const wxString& monitor::GetDisplaySize(void) const
{  // return display size

  return(displaySize);
}

const wxString& monitor::GetGamma(void) const
{  // return gamma

  return(gamma);
}

const wxString& monitor::GetIdComment(void) const
{  // return identifier Comment

  return(identifierComment);
}

const wxString& monitor::GetHorSyncComment(void) const
{  // return horizontal sync Comment

  return(horSyncComment);
}

const wxString& monitor::GetVertRefComment(void) const
{  // return vertical refresh Comment

  return(vertRefreshComment);
}

const wxString& monitor::GetDisplaySizeComment(void) const
{  // return display size Comment

  return(displaySizeComment);
}

const wxString& monitor::GetGammaComment(void) const
{  // return gamma Comment

  return(gammaComment);
}

const option& monitor::GetOption(const unsigned int index) const
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::GetOption"), wxICON_ERROR);
  }

  return(options.Get(index));
}

option& monitor::GetOptionE(const unsigned int index)
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::GetOptionE"), wxICON_ERROR);
  }

  return(options[index]);
}

unsigned int monitor::GetOptionSize(void) const
{  // return size of options

  return(options.GetSize());
}

const option& monitor::GetModeline(const unsigned int index) const
{  // get modeline

  if (index>=modelines.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::GetModeline"), wxICON_ERROR);
  }

  return(modelines.Get(index));
}

option& monitor::GetModelineE(const unsigned int index)
{  // get modeline

  if (index>=modelines.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("monitor::GetModelineE"), wxICON_ERROR);
  }

  return(modelines[index]);
}

unsigned int monitor::GetModelineSize(void) const
{  // return number of modelines

  return(modelines.GetSize());
}


