#ifndef MONITOR_H
#define MONITOR_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionList.h"

// **************************
// Class Definition
// **************************

class monitor
{
public:
  monitor(void);   // constructor
  ~monitor(void);   // destructor
  monitor(const monitor &mon); // copy constructor

  monitor operator=(const monitor &mon); // copy constructor

  void AddComment(const wxString& com);      // set comment
  void SetId(const wxString& id, const wxString& com=wxEmptyString);      // set identifier
  void SetHorSync(const wxString& hor, const wxString& com=wxEmptyString);  // set horizontal synchronisation
  void SetVertRef(const wxString& vert, const wxString& com=wxEmptyString);    // set vertical refresh
  void SetDisplaySize(const wxString& size, const wxString& com=wxEmptyString);  // set display size
  void SetGamma(const wxString& gamma, const wxString& com=wxEmptyString);  // set gamma correction

  const wxArrayString& GetComment(void) const;           // return comment
  const wxString& GetId(void) const;           // return identifier
  const wxString& GetHorSync(void) const;       // return horizontal synchronisation
  const wxString& GetVertRef(void) const;       // return vertical refresh
  const wxString& GetDisplaySize(void) const;    // return display size
  const wxString& GetGamma(void) const;         // return gamma value
  const wxString& GetIdComment(void) const;           // return identifier comment
  const wxString& GetHorSyncComment(void) const;       // return horizontal synchronisation comment
  const wxString& GetVertRefComment(void) const;       // return vertical refresh comment
  const wxString& GetDisplaySizeComment(void) const;    // return display size comment
  const wxString& GetGammaComment(void) const;         // return gamma value comment

  void RemoveOption(const unsigned int index);    // remove option
  void AddOption(const option &opt);              // add option
  void SetOption(const unsigned int index, const option &opt); // set option

  option& GetOptionE(const unsigned int index);                // get option
  const option& GetOption(const unsigned int index) const;     // get option
  unsigned int GetOptionSize(void) const;                      // return size of options

  void RemoveModeline(const unsigned int index);    // remove modeline
  void AddModeline(const option &opt);              // add modeline
  void SetModeline(const unsigned int index, const option &opt); // set modeline

  option& GetModelineE(const unsigned int index);                // get modeline
  const option& GetModeline(const unsigned int index) const;     // get modeline
  unsigned int GetModelineSize(void) const;                      // return number of modelines

  void Clear(void);          // clear everything

private:
  wxString identifier;      // monitor identifier
  wxString horSync;         // horizontal synchronisation
  wxString vertRefresh;     // vertical refresh
  wxString displaySize;     // display size
  wxString gamma;           // gamma correction

  // Note: Any additional settings will not be recognized like:
  // VendorName, ModelName, Gamma, UseMode, Modes.

  wxArrayString comment;                  // comment
  wxString identifierComment;      // monitor identifier comment
  wxString horSyncComment;         // horizontal synchronisation comment
  wxString vertRefreshComment;     // vertical refresh comment
  wxString displaySizeComment;     // display size comment
  wxString gammaComment;           // gamma correction comment
  optionList options;     // all options
  optionList modelines;    // all options
};

#endif // MONITOR_H
