
// **************************************
// Header Files
// **************************************

#include "optionList.h"

// **************************
// Class Declaration
// **************************

optionList::optionList(void)
{  // constructor
  size=0;
  dList=NULL;
}

optionList::~optionList(void)
{  // destructor
  if (dList) delete [] dList;
  dList=NULL;
}

optionList::optionList(const optionList &dis)
{  // copy constructor

  size=dis.GetSize();
  dList=new option[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }
}

optionList optionList::operator=(const optionList &dis)
{  // copy constructor

  Clear();

  size=dis.GetSize();
  dList=new option[size];

  for (unsigned int i=0; i<size;i++)
  {
    dList[i]=dis.Get(i);
  }

  return(*this);
}

void optionList::Remove(const unsigned int index)
{  // remove a option

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("optionList::Remove"), wxICON_ERROR);
    return;
  }

  unsigned int i;  // loop counter

  if (size>1)
  {
    option *dis=new option[size-1];

    for (i=0; i<index; i++) dis[i]=dList[i];        // copy old entries
    for (i=index+1; i<size; i++) dis[i-1]=dList[i]; // and ignore index

    if (dList) delete [] dList;   // delete old list
    dList=dis;         // set pointer
    dis=NULL;
  }
  else
  {
    if (dList) delete [] dList;   // delete old list
    dList=NULL;         // set pointer
  }

  size--;              // set size
}

void optionList::Add(const option& dis)
{  // add an option and value

  option *dL=new option[size+1];

  for (unsigned int i=0; i<size; i++) dL[i]=dList[i]; // copy old entries

  dL[size]=dis;   // set las entry

  if (dList) delete [] dList;   // delete old list
  dList=dL;         // set pointer
  dL=NULL;

  size++;
}

void optionList::Add(const wxString& opt, const wxString& val, const wxString& com)
{  // add option

  option tempOption(opt, val, com);

  option *dL=new option[size+1];

  for (unsigned int i=0; i<size; i++) dL[i]=dList[i]; // copy old entries

  dL[size]=tempOption;   // set las entry

  if (dList) delete [] dList;   // delete old list
  dList=dL;         // set pointer
  dL=NULL;

  size++;
}
void optionList::Clear(void)
{    // clear everything

  if (dList) delete [] dList;
  dList=NULL;

  size=0;
}

const option& optionList::Get(const unsigned int index) const
{  // get single option

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("optionList::Get"), wxICON_ERROR);
  }

  return(dList[index]);
}

option& optionList::operator[](const unsigned int index)
{  // get single device

  if (index>=size)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("optionList::operator[]"), wxICON_ERROR);
    return(dList[index]);  // return empty device
  }

  return(dList[index]);
}


unsigned int optionList::GetSize(void) const
{  // return size

  return(size);

}
