
// **************************************
// Header Files
// **************************************

#include "screen.h"

// **************************
// Class Declaration
// **************************

screen::screen(void)
{  // constructor
}

screen::~screen(void)
{  // destructor
}

screen::screen(const screen &scr)
{  // copy constructor

  identifier=scr.GetId();
  monitorEntry=scr.GetMonitor();
  deviceEntry=scr.GetDevice();
  defaultDepth=scr.GetDefaultDepth();
  identifierComment=scr.GetIdComment();
  monitorEntryComment=scr.GetMonitorComment();
  deviceEntryComment=scr.GetDeviceComment();
  defaultDepthComment=scr.GetDefaultDepthComment();
  comment=scr.GetComment();

  for (unsigned int i=0; i<scr.GetOptionSize(); i++)
  {
    AddOption(scr.GetOption(i));
  }

  for (unsigned int j=0; j<scr.GetDisplaySize(); j++)
  {
    AddDisplay(scr.GetDisplay(j));
  }

}

screen screen::operator=(const screen &scr)
{  // copy constructor

  Clear();

  identifier=scr.GetId();
  monitorEntry=scr.GetMonitor();
  deviceEntry=scr.GetDevice();
  defaultDepth=scr.GetDefaultDepth();
  identifierComment=scr.GetIdComment();
  monitorEntryComment=scr.GetMonitorComment();
  deviceEntryComment=scr.GetDeviceComment();
  defaultDepthComment=scr.GetDefaultDepthComment();
  comment=scr.GetComment();

  for (unsigned int i=0; i<scr.GetOptionSize(); i++)
  {
    AddOption(scr.GetOption(i));
  }

  for (unsigned int j=0; j<scr.GetDisplaySize(); j++)
  {
    AddDisplay(scr.GetDisplay(j));
  }

  return(*this);
}

void screen::AddComment(const wxString& com)
{  // set comment
  comment.Add(com);
}

void screen::SetId(const wxString& id, const wxString& com)
{  // set identifier

  identifier=id;
  identifierComment=com;
}

void screen::SetMonitor(const wxString& mon, const wxString& com)
{  // set monitor

  monitorEntry=mon;
  monitorEntryComment=com;
}

void screen::SetDevice(const wxString& dev, const wxString& com)
{  // set device

  deviceEntry=dev;
  deviceEntryComment=com;
}

void screen::SetDefaultDepth(const wxString& dd, const wxString& com)
{  // set default depth

  defaultDepth=dd;
  defaultDepthComment=com;
}

void screen::RemoveOption(const unsigned int index)
{  // remove option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::RemoveOption"), wxICON_ERROR);
    return;
  }

  options.Remove(index);
}

void screen::AddOption(const option &opt)
{  // add option

  options.Add(opt);
}

void screen::SetOption(const unsigned int index, const option& opt)
{  // set option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::SetOption"), wxICON_ERROR);
    return;
  }

  options[index]=opt;
}

void screen::RemoveDisplay(const unsigned int index)
{  // remove display

  if (index>=dList.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::RemoveDisplay"), wxICON_ERROR);
    return;
  }

  dList.Remove(index);
}

void screen::AddDisplay(const display& dis)
{  // add display

  dList.Add(dis);
}

void screen::Clear(void)
{    // clear everything

  identifier=wxEmptyString;
  monitorEntry=wxEmptyString;
  deviceEntry=wxEmptyString;
  defaultDepth=wxEmptyString;
  identifierComment=wxEmptyString;
  monitorEntryComment=wxEmptyString;
  deviceEntryComment=wxEmptyString;
  defaultDepthComment=wxEmptyString;
  comment.Clear();
  options.Clear();
  dList.Clear();

}

const wxArrayString& screen::GetComment(void) const
{  // return comment

  return(comment);
}

const wxString& screen::GetId(void) const
{  // return identifier

  return(identifier);
}

const wxString& screen::GetMonitor(void) const
{  // return monitor

  return(monitorEntry);
}

const wxString& screen::GetDevice(void) const
{  // return device

  return(deviceEntry);
}

const wxString& screen::GetDefaultDepth(void) const
{  // return default depth

  return(defaultDepth);
}

const wxString& screen::GetIdComment(void) const
{  // return identifier Comment

  return(identifierComment);
}

const wxString& screen::GetMonitorComment(void) const
{  // return monitor Comment

  return(monitorEntryComment);
}

const wxString& screen::GetDeviceComment(void) const
{  // return device Comment

  return(deviceEntryComment);
}

const wxString& screen::GetDefaultDepthComment(void) const
{  // return default depth Comment

  return(defaultDepthComment);
}

const option& screen::GetOption(const unsigned int index) const
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::GetOption"), wxICON_ERROR);
  }

  return(options.Get(index));
}

option& screen::GetOptionE(const unsigned int index)
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::GetOptionE"), wxICON_ERROR);
  }

  return(options[index]);
}

unsigned int screen::GetOptionSize(void) const
{  // return size of options

  return(options.GetSize());
}


const display& screen::GetDisplay(const unsigned int index) const
{  // get display

  if (index>=dList.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::GetDisplay"), wxICON_ERROR);
  }

  return(dList.Get(index));
}

display& screen::GetDisplayE(const unsigned int index)
{  // get display

  if (index>=dList.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("screen::GetDisplay"), wxICON_ERROR);
    return(dList[index]);
  }
  return(dList[index]);
}

unsigned int screen::GetDisplaySize(void) const
{  // return number of display sections

  return(dList.GetSize());

}

