#ifndef SCREEN_H
#define SCREEN_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionList.h"
#include "displayList.h"

// **************************
// Class Definition
// **************************

class screen
{
public:
  screen(void);   // constructor
  ~screen(void);   // destructor
  screen(const screen &scr); // copy constructor

  screen operator=(const screen &scr); // copy constructor

  void AddComment(const wxString& com);      // set comment
  void SetId(const wxString& id, const wxString& com=wxEmptyString);      // set identifier
  void SetMonitor(const wxString& mon, const wxString& com=wxEmptyString);  // set monitor
  void SetDevice(const wxString& dev, const wxString& com=wxEmptyString);    // set device
  void SetDefaultDepth(const wxString& dd, const wxString& com=wxEmptyString);  // set default depth

  const wxArrayString& GetComment(void) const;           // return comment
  const wxString& GetId(void) const;           // return identifier
  const wxString& GetMonitor(void) const;       // return monitor
  const wxString& GetDevice(void) const;         // return device
  const wxString& GetDefaultDepth(void) const;    // return default depth
  const wxString& GetIdComment(void) const;           // return identifier comment
  const wxString& GetMonitorComment(void) const;       // return monitor comment
  const wxString& GetDeviceComment(void) const;         // return device comment
  const wxString& GetDefaultDepthComment(void) const;    // return default depth comment

  void RemoveDisplay(const unsigned int index);  // remove display
  void AddDisplay(const display& dis);        // add display

  const display& GetDisplay(const unsigned int index) const;     // get single display
  display& GetDisplayE(const unsigned int index);     // get single display
  unsigned int GetDisplaySize(void) const;                 // return number of displays

  void RemoveOption(const unsigned int index);    // remove option
  void AddOption(const option &opt);              // add option
  void SetOption(const unsigned int index, const option &opt); // set option

  option& GetOptionE(const unsigned int index);                // get option
  const option& GetOption(const unsigned int index) const;     // get option
  unsigned int GetOptionSize(void) const;                      // return size of options

  void Clear(void);          // clear everything

private:
  wxString identifier;      // screen identifier
  wxString monitorEntry;     // monitor
  wxString deviceEntry;       // device entry
  wxString defaultDepth;    // default depth

  // Note: Any additional settings will not be recognized like:
  // VideoAdaptor, DefaultFbBpp.

  wxArrayString comment;
  wxString identifierComment;
  wxString monitorEntryComment;
  wxString deviceEntryComment;
  wxString defaultDepthComment;
  displayList dList;     // all display subsections
  optionList options;    // all options
};

#endif // SCREEN_H
