
// **************************************
// Header Files
// **************************************

#include "serverLayout.h"

// **************************
// Class Declaration
// **************************

serverLayout::serverLayout(void)
{  // constructor
  screenSize=0;
  iDeviceSize=0;
  iDeviceOptions=NULL;
}

serverLayout::~serverLayout(void)
{  // destructor

  if (iDeviceOptions) delete [] iDeviceOptions;
  iDeviceOptions=NULL;
}

serverLayout::serverLayout(const serverLayout &ser)
{  // copy constructor

  screenSize=0;
  iDeviceSize=0;
  iDeviceOptions=NULL;

  identifier=ser.GetId();
  identifierComment=ser.GetIdComment();
  comment=ser.GetComment();

  for (unsigned int i=0; i<ser.GetScreenSize(); i++)
  {
    AddScreen(ser.GetScreen(i), ser.GetScreenNumber(i), ser.GetScreenPosition(i), ser.GetSecondScreen(i), ser.GetScreenComment(i));
  }

  for (unsigned int j=0; j<ser.GetInputDeviceSize(); j++)
  {
    AddInputDevice(ser.GetInputDevice(j), ser.GetInputDeviceComment(j));

    for (unsigned int l=0; l<ser.GetInputDeviceOptionSize(j); l++)
    {
      AddInputDeviceOption(j, ser.GetInputDeviceOption(j,l));
    }
  }

  for (unsigned int k=0; k<ser.GetOptionSize(); k++)
  {
    AddOption(ser.GetOption(k));
  }

}

serverLayout serverLayout::operator=(const serverLayout &ser)
{  // copy constructor

  Clear();

  identifier=ser.GetId();
  identifierComment=ser.GetIdComment();
  comment=ser.GetComment();

  for (unsigned int i=0; i<ser.GetScreenSize(); i++)
  {
    AddScreen(ser.GetScreen(i), ser.GetScreenNumber(i), ser.GetScreenPosition(i), ser.GetSecondScreen(i), ser.GetScreenComment(i));
  }

  for (unsigned int j=0; j<ser.GetInputDeviceSize(); j++)
  {
    AddInputDevice(ser.GetInputDevice(j), ser.GetInputDeviceComment(j));

    for (unsigned int l=0; l<ser.GetInputDeviceOptionSize(j); l++)
    {
      AddInputDeviceOption(j, ser.GetInputDeviceOption(j,l));
    }
  }

  for (unsigned int k=0; k<ser.GetOptionSize(); k++)
  {
    AddOption(ser.GetOption(k));
  }

  return(*this);
}

void serverLayout::AddComment(const wxString& com)
{  // set comment

  comment.Add(com);
}

void serverLayout::SetId(const wxString& id, const wxString& com)
{  // set identifier

  identifier=id;
  identifierComment=com;
}

void serverLayout::Clear(void)
{    // clear everything

  identifier=wxEmptyString;
  identifierComment=wxEmptyString;
  comment.Clear();
  screenEntry.Clear();
  screenComment.Clear();
  screenNumber.Clear();
  screenPosition.Clear();
  screenEntry2.Clear();
  screenSize=0;
  iDeviceEntry.Clear();
  iDeviceComment.Clear();
  if (iDeviceOptions) delete [] iDeviceOptions;
  iDeviceOptions=NULL;
  iDeviceSize=0;
  options.Clear();
}

const wxArrayString& serverLayout::GetComment(void) const
{  // return comment

  return(comment);
}

const wxString& serverLayout::GetId(void) const
{  // return identifier

  return(identifier);
}

const wxString& serverLayout::GetIdComment(void) const
{  // return identifier comment

  return(identifierComment);
}

void serverLayout::RemoveScreen(const unsigned int index)
{  // remove screen

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::RemoveScreen"), wxICON_ERROR);
    return;
  }

  screenEntry.RemoveAt(index);
  screenComment.RemoveAt(index);
  screenNumber.RemoveAt(index);
  screenPosition.RemoveAt(index);
  screenEntry2.RemoveAt(index);
  screenSize--;
}

void serverLayout::AddScreen(const wxString& id, const wxString& num, const wxString &pos, const wxString& second, const wxString& com)
{ // add a screen

  screenEntry.Add(id);
  screenComment.Add(com);
  screenNumber.Add(num);
  screenPosition.Add(pos);
  screenEntry2.Add(second);
  screenSize++;
}

const wxString& serverLayout::GetScreen(const unsigned int index) const
{  // get screen id

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetScreen"), wxICON_ERROR);
  }

  return(screenEntry.Item(index));
}

const wxString& serverLayout::GetScreenComment(const unsigned int index) const
{  // get screen comment

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetScreenComment"), wxICON_ERROR);
  }

  return(screenComment.Item(index));
}

const wxString& serverLayout::GetScreenNumber(const unsigned int index) const
{ // get screen number

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetScreenNumber"), wxICON_ERROR);
  }

  return(screenNumber.Item(index));

}

const wxString& serverLayout::GetScreenPosition(const unsigned int index) const
{  // get screen position

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetScreenPosition"), wxICON_ERROR);
  }

  return(screenPosition.Item(index));

}

const wxString& serverLayout::GetSecondScreen(const unsigned int index) const
{  // get screen position

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetSecondScreen"), wxICON_ERROR);
  }

  return(screenEntry2.Item(index));

}

unsigned int serverLayout::GetScreenSize(void) const
{  // return number of screens
  return(screenSize);
}

void serverLayout::RemoveInputDevice(const unsigned int index)
{  // remove input device

  if (index>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::RemoveInputDevice"), wxICON_ERROR);
    return;
  }

  iDeviceEntry.RemoveAt(index);
  iDeviceComment.RemoveAt(index);

  unsigned int i;  // loop counter

  if (iDeviceSize>1)
  {
    optionList *dis=new optionList[iDeviceSize-1];

    for (i=0; i<index; i++) dis[i]=iDeviceOptions[i];        // copy old entries
    for (i=index+1; i<iDeviceSize; i++) dis[i-1]=iDeviceOptions[i]; // and ignore index

    if (iDeviceOptions) delete [] iDeviceOptions;   // delete old list
    iDeviceOptions=dis;         // set pointer
    dis=NULL;
  }
  else
  {
    if (iDeviceOptions) delete [] iDeviceOptions;   // delete old list
    iDeviceOptions=NULL;         // set pointer
  }

  iDeviceSize--;

}

void serverLayout::AddInputDevice(const wxString& id, const wxString& com)
{ // add an input device

  iDeviceEntry.Add(id);
  iDeviceComment.Add(com);

  optionList *dL=new optionList[iDeviceSize+1];

  for (unsigned int i=0; i<iDeviceSize; i++) dL[i]=iDeviceOptions[i]; // copy old entries

  // leave last entry open

  if (iDeviceOptions) delete [] iDeviceOptions;   // delete old list
  iDeviceOptions=dL;         // set pointer
  dL=NULL;

  iDeviceSize++;
}


void serverLayout::RemoveInputDeviceOption(const unsigned int index1, const unsigned index2)
{  // remove input device

  if (index1>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::RemoveInputDeviceOption"), wxICON_ERROR);
    return;
  }

  iDeviceOptions[index1].Remove(index2);
}

void serverLayout::AddInputDeviceOption(const unsigned int index, const option& opt)
{ // add an input device

  if (index>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::AddInputDeviceOption"), wxICON_ERROR);
    return;
  }

  iDeviceOptions[index].Add(opt);
}

void serverLayout::SetInputDeviceOption(const unsigned int index1, const unsigned index2, const option& opt)
{  // set an option and value

  if (index1>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetInputDeviceOption"), wxICON_ERROR);
    return;
  }

  iDeviceOptions[index1][index2]=opt;
}

const wxString& serverLayout::GetInputDevice(const unsigned int index) const
{  // get input device id

 if (index>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetInputDevice"), wxICON_ERROR);
  }

  return(iDeviceEntry.Item(index));

}

const wxString& serverLayout::GetInputDeviceComment(const unsigned int index) const
{  // get input device comment

 if (index>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetInputDeviceComment"), wxICON_ERROR);
  }

  return(iDeviceComment.Item(index));

}


const option& serverLayout::GetInputDeviceOption(const unsigned int index1, const unsigned int index2) const
{  // get input device option

 if (index1>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetInputDevice"), wxICON_ERROR);
  }

  return(iDeviceOptions[index1].Get(index2));

}

option& serverLayout::GetInputDeviceOptionE(const unsigned int index1, const unsigned int index2)
{  // get input device option

 if (index1>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetInputDeviceE"), wxICON_ERROR);
  }

  return(iDeviceOptions[index1][index2]);
}

unsigned int serverLayout::GetInputDeviceSize(void) const
{  // return number of input devices
  return(iDeviceSize);
}

unsigned int serverLayout::GetInputDeviceOptionSize(const unsigned int index) const
{  // return number of input device options

 if (index>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetInputDeviceOptionSize"), wxICON_ERROR);
    return(0);
  }

  return(iDeviceOptions[index].GetSize());
}

void serverLayout::RemoveOption(const unsigned int index)
{  // remove option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::RemoveOption"), wxICON_ERROR);
    return;
  }

  options.Remove(index);
}

void serverLayout::AddOption(const option &opt)
{  // add option

  options.Add(opt);
}

void serverLayout::SetOption(const unsigned int index, const option& opt)
{  // set option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetOption"), wxICON_ERROR);
    return;
  }

  options[index]=opt;
}

const option& serverLayout::GetOption(const unsigned int index) const
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetOption"), wxICON_ERROR);
  }

  return(options.Get(index));
}

option& serverLayout::GetOptionE(const unsigned int index)
{  // get option

  if (index>=options.GetSize())
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::GetOptionE"), wxICON_ERROR);
  }

  return(options[index]);
}

unsigned int serverLayout::GetOptionSize(void) const
{  // return size of options

  return(options.GetSize());
}

void serverLayout::SetScreen(const unsigned int index, const wxString& scr, const wxString& com)
{            // set screen id

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetScreen"), wxICON_ERROR);
    return;
  }

  screenEntry[index]=scr;
  screenComment[index]=com;
}

void serverLayout::SetScreenNumber(const unsigned int index, const wxString& num)
{      // set screen number

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetScreenNumber"), wxICON_ERROR);
    return;
  }

  screenNumber[index]=num;

}

void serverLayout::SetScreenPosition(const unsigned int index, const wxString& pos)
{   // set screen position

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetScreenPosition"), wxICON_ERROR);
    return;
  }

  screenPosition[index]=pos;

}

void serverLayout::SetSecondScreen(const unsigned int index, const wxString& scr)
{         // set second screen id

  if (index>=screenSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetSecondScreen"), wxICON_ERROR);
    return;
  }

  screenEntry2[index]=scr;

}

void serverLayout::SetInputDevice(const unsigned int index, const wxString& dev, const wxString& com)
{  // set input device id

  if (index>=iDeviceSize)
  {
    wxMessageBox(_("Try to access item outside boundaries!"), _T("serverLayout::SetInputDevice"), wxICON_ERROR);
    return;
  }

  iDeviceEntry[index]=dev;
  iDeviceComment[index]=com;
}

