#ifndef SERVERLAYOUT_H
#define SERVERLAYOUT_H

// **************************************
// Header Files
// **************************************

#include "global.h"
#include "optionList.h"

// **************************
// Class Definition
// **************************

class serverLayout
{
public:
  serverLayout(void);    // constructor
  ~serverLayout(void);   // destructor
  serverLayout(const serverLayout &ser); // copy constructor

  serverLayout operator=(const serverLayout &ser); // copy constructor

  void AddComment(const wxString& com);      // set comment
  void SetId(const wxString& id, const wxString& com=wxEmptyString);      // set identifier

  const wxArrayString& GetComment(void) const;           // return comment
  const wxString& GetId(void) const;           // return identifier
  const wxString& GetIdComment(void) const;           // return identifier comment

  void RemoveScreen(const unsigned int index);               // remove screen
  void AddScreen(const wxString& id, const wxString& num=wxEmptyString, const wxString &pos=wxEmptyString, const wxString &second=wxEmptyString, const wxString& com=wxEmptyString);  // add a screen

  void SetScreen(const unsigned int index, const wxString& scr, const wxString& com=wxEmptyString);             // set screen id
  void SetScreenNumber(const unsigned int index, const wxString& num);       // set screen number
  void SetScreenPosition(const unsigned int index, const wxString& pos);     // set screen position
  void SetSecondScreen(const unsigned int index, const wxString& scr);       // set second screen id

  const wxString& GetScreen(const unsigned int index) const;           // get screen id
  const wxString& GetScreenComment(const unsigned int index) const;           // get screen comment
  const wxString& GetScreenNumber(const unsigned int index) const;     // get screen number
  const wxString& GetScreenPosition(const unsigned int index) const;    // get screen position
  const wxString& GetSecondScreen(const unsigned int index) const;      // get second screen (for position)
  unsigned int GetScreenSize(void) const;                       // return number of screens

  void RemoveInputDevice(const unsigned int index);               // remove input device
  void AddInputDevice(const wxString& id, const wxString& com=wxEmptyString);                       // add an input device
  void SetInputDevice(const unsigned int index, const wxString& dev, const wxString& com=wxEmptyString);   // set input device id

  const wxString& GetInputDevice(const unsigned int index) const;           // get input device id
  const wxString& GetInputDeviceComment(const unsigned int index) const;           // get input device comment
  unsigned int GetInputDeviceSize(void) const;                       // return number of input devices

  void RemoveInputDeviceOption(const unsigned int index1, const unsigned int index2);    // remove option
  void AddInputDeviceOption(const unsigned int index, const option &opt);              // add option
  void SetInputDeviceOption(const unsigned int index1, const unsigned int index2, const option &opt); // set option

  option& GetInputDeviceOptionE(const unsigned int index1, const unsigned int index2);                // get option
  const option& GetInputDeviceOption(const unsigned int index1, const unsigned int index2) const;     // get option
  unsigned int GetInputDeviceOptionSize(const unsigned int index) const;                      // return size of options

  void RemoveOption(const unsigned int index);    // remove option
  void AddOption(const option &opt);              // add option
  void SetOption(const unsigned int index, const option &opt); // set option

  option& GetOptionE(const unsigned int index);                // get option
  const option& GetOption(const unsigned int index) const;     // get option
  unsigned int GetOptionSize(void) const;                      // return size of options

  void Clear(void);          // clear everything

private:
  wxString identifier;             // identifier
  wxArrayString screenEntry;      // screens
  wxArrayString screenNumber;      // screen-number of each screen
  wxArrayString screenPosition;    // screen position
  wxArrayString screenEntry2;      // screens2
  unsigned int screenSize;         // number of screens
  wxArrayString iDeviceEntry;      // input devices
  optionList *iDeviceOptions;   // input device options
  unsigned int iDeviceSize;        // number of input devices

  wxArrayString comment;
  wxString identifierComment;
  wxArrayString screenComment;
  wxArrayString iDeviceComment;

  optionList options;    // all options
};

#endif // SERVERLAYOUT_H
